@@ -49,7 +49,7 @@ CATEGORY_TO_SUBCATEGORY = {
         "Sharing",
         "Productive hacks",
     ],
-    "Cool tools": [
+    "Cool Tools": [
         "Better output",
         "Tracking",
         "Data",
@@ -92,19 +92,23 @@ def get_save_code_from_questionary():
 def get_code(code_link: str):
     if code_link == "":
         return
- 
+
     file_name = get_file_name(code_link)
-    if file_name.endswith('.ipynb'):
-        console.print("This is a notebook so the source code will not be printed on the terminal.")
+    if file_name.endswith(".ipynb"):
+        console.print(
+            "This is a notebook so the source code will not be printed on the terminal."
+        )
     else:
         code = print_code(code_link, file_name)
-    
+
     save_code = get_save_code_from_questionary()
 
     if save_code == "Yes":
         with open(file_name, "w") as f:
             f.write(code)
-        console.print(f"The file {file_name} is saved to your current directory :sparkles:")
+        console.print(
+            f"The file {file_name} is saved to your current directory :sparkles:"
+        )
 
 
 def get_color(num: int):
